;; Generated package description from helm-core.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "helm-core" "4.0.7.0.20260811.46" "Development files for Helm" '((emacs "25.1") (async "1.9.9")) :commit "acff7751af0623f1bbebb1f3bf1ee4831f7f5035" :authors '(("Thierry Volpiatto" . "thievol@posteo.net")) :maintainer '("Thierry Volpiatto" . "thievol@posteo.net") :url "https://emacs-helm.github.io/helm/")
